@@ -1,7 +1,8 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2022-2024, by Samuel Williams.
+# Copyright, 2022-2025, by Samuel Williams.
+# Copyright, 2025, by Francisco Mejia.
 
 require "console"
 
@@ -59,8 +60,12 @@ module Protocol
 						
 						# I'm not sure what sane defaults should be here:
 						CGI::SERVER_NAME => server_name,
-						CGI::SERVER_PORT => server_port,
 					}
+
+					# SERVER_PORT is optional but must not be set if it is not present.
+					if server_port
+						env[CGI::SERVER_PORT] = server_port
+					end
 					
 					self.unwrap_request(request, env)
 					
